#include <stdlib.h>
#include <stdio.h>
#include "SDL.h"
#include <math.h>

typedef int GfxColor;

typedef struct
{
  char red, green, blue;
}
GfxRGB;

typedef struct
{
  int x;
  int y;
}
GfxTuple;

typedef struct
{
  int length;
  GfxColor *color;
}
GfxPalette;

/* initialize SDL graphics */
void GfxInit(unsigned int width, unsigned int height, unsigned int bpp);

/* get graphix information (width, height, bpp) */
inline int GfxWidth();
inline int GfxHeight();
inline int GfxBpp();

/* verify if position is inside clipping area */
inline int GfxValid(int x, int y);

/* calculate color value rgb -> int (each channel is a value from 0 to 255) */
GfxColor (*GfxEnRgb)(unsigned char r, unsigned char g, unsigned char b);

/* calculate color value int -> rgb (each channel is a value from 0 to 255) */
void (*GfxDeRgb)(GfxColor c, unsigned char *r, unsigned char *g, unsigned char *b);

/* transform x and y coordinates in point structure */
GfxTuple GfxPoint(int x, int y);

/* set a point on position (x,y), color c */
void (*GfxPSet)(int x, int y, GfxColor c);

/* get color of point position(x,y) */
int (*GfxPGet)(int, int);

/* show the changed screen */
inline void GfxUpdate(int x, int y, int w, int h);

/* show the changed screen */
inline void GfxUpdateAll();

/* BitBlockTransfer */
void GfxBlt();

/* clear screen */
void GfxCls();

/* draw line with Bresenham Algorithm */
void GfxLine(int x1, int y1, int x2, int y2, int color);

/* draw rectangle */
void GfxEmptyBox(int startx,  int starty,  int endx,  int endy,  int color);

/* draw filled rectangle */
void GfxFullBox(int startx,  int starty,  int endx,  int endy,  int color);

/* draw circle */
void GfxFullCircle(int x, int y, int radius,  int color);

/* create palette and fill it with rainbow colors */
GfxPalette GfxCreateRainbowPalette(int length);

/* create palette filles with grey colors */
GfxPalette GfxCreateGreyPalette(int length);

/* choose a random color */
GfxColor GfxRndColor();

/* save content of window to file */
int GfxDumpScreen(char* name);

/* simplified isometric transformation (zoomed and centered) */
inline int GfxIsoX(int x, int y, int z, int zoom);
inline int GfxIsoY(int x, int y, int z, int zoom);

